@@ -66,6 +66,6 @@ class TabixContainer(RowContainer):
 
 
 import sys    
-from .integration import integrate
+from petlx.integration import integrate
 integrate(sys.modules[__name__])
 
