@@ -16,7 +16,8 @@ https://bitbucket.org/ericgazoni/openpyxl/wiki/Home or try pip install openpyxl.
 """
 
 
-def fromxlsx(filename, sheet=None, range=None, **kwargs):
+def fromxlsx(filename, sheet=None, range_string=None, row_offset=0,
+             column_offset=0, **kwargs):
     """
     Extract a table from a sheet in an Excel (.xlsx) file.
     
@@ -24,23 +25,43 @@ def fromxlsx(filename, sheet=None, range=None, **kwargs):
 
     .. versionchanged:: 0.15
 
-    The ``sheet`` argument can be omitted, in which case the first sheet in the workbook is used by default.
+    The ``sheet`` argument can be omitted, in which case the first sheet in
+    the workbook is used by default.
 
-    The ``range`` argument can be used to provide a range string specifying a range of cells to extract.
+    The ``range_string`` argument can be used to provide a range string
+    specifying a range of cells to extract.
 
-    Any other keyword arguments are passed through to :func:`openpyxl.load_workbook()`.
+    The ``row_offset`` and ``column_offset`` arguments can be used to
+    specify offsets.
+
+    Any other keyword arguments are passed through to
+    :func:`openpyxl.load_workbook()`.
+
+    .. versionchanged:: 0.18
+
+    The keyword argument 'range' has been renamed to 'range_string' for
+    consistency with the underlying openpyxl API.
 
     """
-    
-    return XLSXView(filename, sheet=sheet, range=range, **kwargs)
+
+    # backwards compatibility
+    if 'range' in kwargs:
+        range_string = kwargs.pop('range')
+
+    return XLSXView(filename, sheet=sheet, range_string=range_string,
+                    row_offset=row_offset, column_offset=column_offset,
+                    **kwargs)
 
 
 class XLSXView(petl.util.RowContainer):
     
-    def __init__(self, filename, sheet=None, range=None, **kwargs):
+    def __init__(self, filename, sheet=None, range_string=None,
+                 row_offset=0, column_offset=0, **kwargs):
         self.filename = filename
         self.sheet = sheet
-        self.range = range
+        self.range_string = range_string
+        self.row_offset = row_offset
+        self.column_offset = column_offset
         self.kwargs = kwargs
 
     def __iter__(self):
@@ -49,9 +70,8 @@ class XLSXView(petl.util.RowContainer):
         except ImportError as e:
             raise UnsatisfiedDependency(e, dep_message)
 
-        use_iterators = self.range is None
         wb = openpyxl.load_workbook(filename=self.filename,
-                                    use_iterators=use_iterators, **self.kwargs)
+                                    use_iterators=True, **self.kwargs)
         if self.sheet is None:
             ws = wb.get_sheet_by_name(wb.get_sheet_names()[0])
         elif isinstance(self.sheet, int):
@@ -59,12 +79,10 @@ class XLSXView(petl.util.RowContainer):
         else:
             ws = wb.get_sheet_by_name(str(self.sheet))
 
-        if self.range is not None:
-            return (tuple(cell.value for cell in row)
-                    for row in ws.range(self.range))
-        else:
-            return (tuple(cell.value for cell in row)
-                    for row in ws.iter_rows())
+        return (tuple(cell.value for cell in row)
+                for row in ws.iter_rows(range_string=self.range_string,
+                                        row_offset=self.row_offset,
+                                        column_offset=self.column_offset))
 
 
 def toxlsx(tbl, filename, sheet=None, encoding='utf-8'):
